"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const Messenger_1 = require("../Messenger");
const ui = __importStar(require("../ui/chat"));
const utils_1 = require("../utils");
function main(args, conf, ks) {
    return __awaiter(this, void 0, void 0, function* () {
        const messenger = new Messenger_1.Messenger(conf);
        messenger.on('close', () => {
            console.error(`The connection to KISS TNC at ${conf.kissPort} is now closed. Exiting.`);
            ui.exit(1);
        });
        messenger.on('tnc-error', (err) => {
            console.error(`The connection to KISS TNC ${conf.kissPort} experienced the following error:`);
            console.error(err);
        });
        messenger.on('message', (message) => {
            if (message.to.callsign === 'CQ' ||
                (message.to.callsign === conf.callsign &&
                    message.to.ssid === conf.ssid)) {
                ui.printReceivedMessage(message, conf.callsign);
            }
        });
        try {
            yield messenger.openTNC();
        }
        catch (err) {
            console.error(`Error opening a serial connection to KISS TNC that should be at ${conf.kissPort}. Are you sure your TNC is running?`);
            console.error(`If you have direwolf installed you can start it in another window with "direwolf -p -q d -t 0"`);
            return 1;
        }
        ui.enter();
        // only sign if the user's config has a signing key
        const sign = typeof conf.signingKey === 'string';
        const callsignSSID = utils_1.stationToCallsignSSID({ callsign: conf.callsign, ssid: conf.ssid });
        yield ui.inputLoop(callsignSSID, messenger, sign);
        return 0;
    });
}
exports.main = main;
//# sourceMappingURL=chat.js.map