"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Messenger_1 = require("../Messenger");
const utils_1 = require("../utils");
function printVerbose(message, raw) {
    let msg = `[verbose] received a packet with `;
    if (message.verification === Messenger_1.Verification.Valid)
        msg += `VALID_SIGNATURE `;
    else if (message.verification === Messenger_1.Verification.NotSigned)
        msg += `NO_SIGNATURE `;
    else if (message.verification === Messenger_1.Verification.Invalid)
        msg += `INVALID_SIGNATURE `;
    else if (message.verification === Messenger_1.Verification.KeyNotFound)
        msg += `UNKNOWN_SIGNATURE `;
    msg += `from ${utils_1.stationToCallsignSSID(message.from)} `;
    msg += `to ${utils_1.stationToCallsignSSID(message.to)}: `;
    if (raw && message.ax25Buffer != null)
        msg += `${message.ax25Buffer.toString('utf8')}`;
    else
        msg += `"${message.message}"`;
    console.error(msg);
}
function printPacket(message, raw) {
    let msg = message.message;
    if (raw && message.ax25Buffer != null)
        msg = message.ax25Buffer.toString('utf8');
    console.log(msg);
}
function main(args, conf, ks) {
    return __awaiter(this, void 0, void 0, function* () {
        const messenger = new Messenger_1.Messenger(conf);
        messenger.on('close', () => {
            console.error(`The connection to KISS TNC at ${conf.kissPort} is now closed. Exiting.`);
            process.exit(1);
        });
        messenger.on('tnc-error', (err) => {
            console.error(`The connection to KISS TNC ${conf.kissPort} experienced the following error:`);
            console.error(err);
            process.exit(1);
        });
        messenger.on('message', (message) => {
            const to = utils_1.callsignSSIDToStation(args.to);
            if (args.verbose)
                printVerbose(message, args.raw);
            if (args.allowAll)
                printPacket(message, args.raw);
            else if (args.allRecipients ||
                (message.to.callsign === to.callsign && message.to.ssid == to.ssid)) {
                if (message.verification === Messenger_1.Verification.Valid) {
                    printPacket(message, args.raw);
                }
                else if (args.allowUnsigned && message.verification === Messenger_1.Verification.NotSigned) {
                    printPacket(message, args.raw);
                }
                else if (args.allowUntrusted && message.verification === Messenger_1.Verification.KeyNotFound) {
                    printPacket(message, args.raw);
                }
                else if (args.allowInvalid && message.verification === Messenger_1.Verification.Invalid) {
                    printPacket(message, args.raw);
                }
            }
        });
        try {
            yield messenger.openTNC();
        }
        catch (err) {
            console.error(`Error opening a serial connection to KISS TNC that should be at ${conf.kissPort}. Are you sure your TNC is running?`);
            console.error(`If you have direwolf installed you can start it in another window with "direwolf -p -q d -t 0"`);
            return 1;
        }
        // await an unending promise to hang indefinitely
        yield new Promise(() => { });
        return 0; // this will never be reached.
    });
}
exports.main = main;
//# sourceMappingURL=receive.js.map