"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const terminal_kit_1 = require("terminal-kit");
const Messenger_1 = require("../Messenger");
const utils_1 = require("../utils");
terminal_kit_1.terminal.on('key', (name, matches, data) => {
    if (matches.includes('CTRL_C') || matches.includes('CTRL_D')) {
        exit(0);
    }
});
const colorMap = {};
const myColorFunction = terminal_kit_1.terminal.cyan;
function getColorFunction(callsign) {
    const choices = [
        terminal_kit_1.terminal.red,
        terminal_kit_1.terminal.green,
        terminal_kit_1.terminal.yellow,
        terminal_kit_1.terminal.blue,
        terminal_kit_1.terminal.magenta,
        terminal_kit_1.terminal.brightRed,
        terminal_kit_1.terminal.brightGreen,
        terminal_kit_1.terminal.brightYellow,
        terminal_kit_1.terminal.brightBlue,
        terminal_kit_1.terminal.brightMagenta
    ];
    if (!colorMap.hasOwnProperty(callsign)) {
        colorMap[callsign] = choices[Math.floor(Math.random() * choices.length)];
    }
    return colorMap[callsign];
}
function enter() {
    terminal_kit_1.terminal.fullscreen();
}
exports.enter = enter;
function exit(code) {
    terminal_kit_1.terminal.processExit(code);
}
exports.exit = exit;
function printReceivedMessage(message, callsign) {
    return __awaiter(this, void 0, void 0, function* () {
        const pos = yield terminal_kit_1.terminal.getCursorLocation();
        if (pos) {
            terminal_kit_1.terminal.moveTo(0, pos.y);
            terminal_kit_1.terminal.insertLine(1);
            printStyledText(message);
            terminal_kit_1.terminal.move(pos.x - 1, 0);
            if (terminal_kit_1.terminal.height === pos.y) {
                if (input) {
                    // term.moveTo(0, term.height)
                    terminal_kit_1.terminal.moveTo(0, terminal_kit_1.terminal.height);
                    myColorFunction(`${callsign}`)(': ');
                    input.redraw();
                }
            }
        }
    });
}
exports.printReceivedMessage = printReceivedMessage;
function inputLoop(callsign, messenger, sign) {
    return __awaiter(this, void 0, void 0, function* () {
        while (true) {
            const text = (yield prompt(callsign)).trim();
            if (text !== '') {
                let to = 'CQ';
                if (text.startsWith('@')) {
                    const space = text.indexOf(' ');
                    const callsign = space === -1 ? text.slice(1) : text.slice(1, space);
                    if (utils_1.isCallsign(callsign) || utils_1.isCallsignSSID(callsign))
                        to = callsign.toUpperCase();
                }
                yield messenger.send(to, text, sign);
            }
            terminal_kit_1.terminal.eraseLine();
            const pos = yield terminal_kit_1.terminal.getCursorLocation();
            terminal_kit_1.terminal.moveTo(0, pos.y);
            myColorFunction(`${callsign}`)(`: ${text}`);
        }
    });
}
exports.inputLoop = inputLoop;
let input;
function prompt(callsign) {
    return __awaiter(this, void 0, void 0, function* () {
        myColorFunction(`\n${callsign}`)(': ');
        input = terminal_kit_1.terminal.inputField({ cancelable: true });
        const message = yield input.promise;
        return message;
    });
}
function printStyledText(message) {
    //// For testing only...
    // const rand = Math.random()
    // if (rand < 0.25) message.verification = Verification.NotSigned
    // else if (rand < 0.50) message.verification = Verification.Valid
    // else if (rand < 0.75) message.verification = Verification.Invalid
    // else message.verification = Verification.KeyNotFound
    const from = utils_1.stationToCallsignSSID(message.from);
    getColorFunction(from)(`${from}`);
    switch (message.verification) {
        case Messenger_1.Verification.NotSigned:
            terminal_kit_1.terminal(' (UNSIGNED): ').dim(`${message.message}`);
            break;
        case Messenger_1.Verification.Valid:
            terminal_kit_1.terminal(`: ${message.message}`);
            break;
        case Messenger_1.Verification.Invalid:
            terminal_kit_1.terminal(' (INVALID SIGNATURE): ').strike(`${message.message}`);
            break;
        case Messenger_1.Verification.KeyNotFound:
            terminal_kit_1.terminal(' (KEY NOT FOUND): ').underline(`${message.message}`);
            break;
    }
    terminal_kit_1.terminal('\n');
}
//# sourceMappingURL=chat.js.map